abacusai.feature_importance — AbacusAI documentation

# `abacusai.feature_importance`

## Module Contents

### Classes

`FeatureImportance` | Feature importance for a specified model monitor

class abacusai.feature_importance.FeatureImportance(client, shapFeatureImportance=None, limeFeatureImportance=None, permutationFeatureImportance=None, nullFeatureImportance=None, lofoFeatureImportance=None, ebmFeatureImportance=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Feature importance for a specified model monitor

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - shapFeatureImportance (dict) – A map of feature name to feature importance, determined by Shap values on a sample dataset.

    - limeFeatureImportance (dict) – A map of feature name to feature importance, determined by Lime contribution values on a sample dataset.

    - permutationFeatureImportance (dict) – A map of feature name to feature importance, determined by permutation importance.

    - nullFeatureImportance (dict) – A map of feature name to feature importance, determined by null feature importance.

    - lofoFeatureImportance (dict) – A map of feature name to feature importance, determined by the Leave One Feature Out method.

    - ebmFeatureImportance (dict) – A map of feature name to feature importance, determined by an Explainable Boosting Machine.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict